@@ -3,7 +3,7 @@
 * Nagios-plugins parse_ini library
 * 
 * License: GPL
-* Copyright (c) 2007 Nagios Plugins Development Team
+* Copyright (c) 2007-2014 Nagios Plugins Development Team
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ static int read_defaults(FILE *f, const char *stanza, np_arg_list **opts);
 static int add_option(FILE *f, np_arg_list **optlst);
 /* internal function to find default file */
 static char* default_file(void);
-/* internal function to stat() files */
+/* internal function to test files access */
 static int test_file(const char* env, int len, const char* file, char* temp_file);
 
 /* parse_locator decomposes a string of the form
@@ -92,23 +92,45 @@ np_arg_list* np_get_defaults(const char *locator, const char *default_section){
 	FILE *inifile=NULL;
 	np_arg_list *defaults=NULL;
 	np_ini_info i;
+	struct stat fstat;
+	bool is_suid_set = np_suid();
+
+	if (is_suid_set && idpriv_temp_drop() == -1) 
+		die(STATE_UNKNOWN, "%s %s\n", _("Can't drop user permissions."), strerror(errno));
 
 	parse_locator(locator, default_section, &i);
-	/* if a file was specified or if we're using the default file */
-	if(i.file != NULL && strlen(i.file) > 0){
-		if(strcmp(i.file, "-")==0){
-			inifile=stdin;
-		} else {
-			inifile=fopen(i.file, "r");
-		}
-		if(inifile==NULL) die(STATE_UNKNOWN, _("Can't read config file"));
-		if(read_defaults(inifile, i.stanza, &defaults)==FALSE)
-			die(STATE_UNKNOWN, _("Invalid section '%s' in config file '%s'\n"), i.stanza, i.file);
+	/* If a file was specified or if we're using the default file. */
+        if (i.file != NULL && strlen(i.file) > 0) {
+                if (strcmp(i.file, "-") == 0) {
+                        inifile = stdin;
+                } else {
+                        /* We must be able to stat() the thing. */
+                        if (lstat(i.file, &fstat) != 0)
+                                die(STATE_UNKNOWN, "%s %s\n", _("Can't read config file."), strerror(errno));
+                        /* The requested file must be a regular file. */
+                        if (!S_ISREG(fstat.st_mode))
+                                die(STATE_UNKNOWN, "%s\n", _("Can't read config file. Requested path is not a regular file."));
+                        /* We must be able to read the requested file. */
+                        if (access(i.file, R_OK|F_OK) != 0)
+                                die(STATE_UNKNOWN, "%s %s\n", _("Can't read config file."), strerror(errno));
+                        /* We need to successfully open the file for reading... */
+                        if ((inifile=fopen(i.file, "r")) == NULL)
+                                die(STATE_UNKNOWN, "%s %s\n", _("Can't read config file."), strerror(errno));
+                }
 
-		free(i.file);
-		if(inifile!=stdin) fclose(inifile);
-	}
+                /* inifile points to an open FILE our ruid/rgid can access, parse its contents. */
+                if (read_defaults(inifile, i.stanza, &defaults) == FALSE)
+                        die(STATE_UNKNOWN, _("Invalid section '%s' in config file '%s'\n"), i.stanza, i.file);
+
+                if (inifile != stdin) fclose(inifile);
+        }
+
+	if (i.file != NULL) free(i.file);
 	free(i.stanza);
+
+	if (is_suid_set && idpriv_temp_restore() == -1) 
+		die(STATE_UNKNOWN, "%s %s\n", _("Can't restore user permissions."), strerror(errno));
+
 	return defaults;
 }
 
@@ -163,7 +185,7 @@ static int read_defaults(FILE *f, const char *stanza, np_arg_list **opts){
 					 * we're dealing with a config error
 					 */
 					case NOSTANZA:
-						die(STATE_UNKNOWN, _("Config file error"));
+						die(STATE_UNKNOWN, "%s\n", _("Config file error"));
 						break;
 					/* we're in a stanza, but for a different plugin */
 					case WRONGSTANZA:
@@ -173,7 +195,7 @@ static int read_defaults(FILE *f, const char *stanza, np_arg_list **opts){
 					case RIGHTSTANZA:
 						ungetc(c, f);
 						if(add_option(f, opts)){
-							die(STATE_UNKNOWN, _("Config file error"));
+							die(STATE_UNKNOWN, "%s\n", _("Config file error"));
 						}
 						status=TRUE;
 						break;
@@ -229,7 +251,7 @@ static int add_option(FILE *f, np_arg_list **optlst){
 	if(optend==NULL) optend=eqptr;
 	--optend;
 	/* ^[[:space:]]*=foo is a syntax error */
-	if(optptr==eqptr) die(STATE_UNKNOWN, _("Config file error\n"));
+	if(optptr==eqptr) die(STATE_UNKNOWN, "%s\n", _("Config file error"));
 	/* continue from '=' to start of value or EOL */
 	for(valptr=eqptr+1; valptr<lineend && isspace(*valptr); valptr++);
 	/* continue to the end of value */
@@ -256,7 +278,7 @@ static int add_option(FILE *f, np_arg_list **optlst){
 		cfg_len+=1;
 	}
 	/* A line with no equal sign isn't valid */
-	if(equals==0) die(STATE_UNKNOWN, _("Config file error\n"));
+	if(equals==0) die(STATE_UNKNOWN, "%s\n", _("Config file error"));
 
 	/* okay, now we have all the info we need, so we create a new np_arg_list
 	 * element and set the argument...
@@ -350,7 +372,6 @@ static char* default_file(void){
  * existence. Returns 1 if found, 0 if not and -1 if test wasn't performed.
  */
 static int test_file(const char* env, int len, const char* file, char* temp_file){
-	struct stat sb;
 
 	/* test if len + filelen + '/' + '\0' fits in temp_file */
 	if((len+strlen(file)+2)>MAX_INPUT_BUFFER)	return -1;
@@ -360,7 +381,7 @@ static int test_file(const char* env, int len, const char* file, char* temp_file
 	strncat(temp_file,"/",len+1);
 	strncat(temp_file,file,len+strlen(file)+1);
 
-	if(stat(temp_file, &sb) != -1) return 1;
+	if(access(temp_file, F_OK) == 0) return 1;
 	return 0;
 }
 
