@@ -1,5 +1,4 @@
 #!/bin/perl -w
-# $Id: check_file_age.pl,v 1.2 2003/10/21 15:56:35 tonvoon Exp $
 
 # check_file_age.pl Copyright (C) 2003 Steven Grimm <koreth-nagios@midwinter.com>
 #
@@ -19,8 +18,8 @@
 #
 # you should have received a copy of the GNU General Public License
 # along with this program (or with Nagios);  if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA
+# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+# Boston, MA 02110-1301, USA
 
 use strict;
 use English;
@@ -33,7 +32,7 @@ use utils qw (%ERRORS &print_revision &support);
 sub print_help ();
 sub print_usage ();
 
-my ($opt_c, $opt_f, $opt_w, $opt_C, $opt_W, $opt_h, $opt_V);
+my ($opt_c, $opt_f, $opt_w, $opt_C, $opt_W, $opt_h, $opt_V, $opt_i);
 my ($result, $message, $age, $size, $st);
 
 $PROGNAME="check_file_age";
@@ -48,6 +47,7 @@ Getopt::Long::Configure('bundling');
 GetOptions(
 	"V"   => \$opt_V, "version"	=> \$opt_V,
 	"h"   => \$opt_h, "help"	=> \$opt_h,
+	"i"   => \$opt_i, "ignore-missing"	=> \$opt_i,
 	"f=s" => \$opt_f, "file"	=> \$opt_f,
 	"w=f" => \$opt_w, "warning-age=f" => \$opt_w,
 	"W=f" => \$opt_W, "warning-size=f" => \$opt_W,
@@ -55,7 +55,7 @@ GetOptions(
 	"C=f" => \$opt_C, "critical-size=f" => \$opt_C);
 
 if ($opt_V) {
-	print_revision($PROGNAME, '$Id: check_file_age.pl,v 1.2 2003/10/21 15:56:35 tonvoon Exp $');
+	print_revision($PROGNAME, '@NP_VERSION@');
 	exit $ERRORS{'OK'};
 }
 
@@ -67,14 +67,21 @@ if ($opt_h) {
 $opt_f = shift unless ($opt_f);
 
 if (! $opt_f) {
-	print "No file specified\n";
+	print "FILE_AGE UNKNOWN: No file specified\n";
 	exit $ERRORS{'UNKNOWN'};
 }
 
-# Examine the file.
-unless (-f $opt_f) {
-	print "$opt_f: File not found\n";
-	exit $ERRORS{'UNKNOWN'};
+# Check that file exists (can be directory or link)
+unless (-e $opt_f) {
+	if ($opt_i) {
+		$result = 'OK';
+		print "FILE_AGE $result: $opt_f doesn't exist, but ignore-missing was set\n";
+		exit $ERRORS{$result};
+
+	} else {
+		print "FILE_AGE CRITICAL: File not found - $opt_f\n";
+		exit $ERRORS{'CRITICAL'};
+	}
 }
 
 $st = File::stat::stat($opt_f);
@@ -91,23 +98,24 @@ elsif (($opt_w and $age > $opt_w) or ($opt_W and $size < $opt_W)) {
 	$result = 'WARNING';
 }
 
-print "$result - $opt_f is $age seconds old and $size bytes\n";
+print "FILE_AGE $result: $opt_f is $age seconds old and $size bytes\n";
 exit $ERRORS{$result};
 
 sub print_usage () {
 	print "Usage:\n";
-	print "  $PROGNAME [-w <secs>] [-c <secs>] [-W <size>] [-C <size>] -f <file>\n";
+	print "  $PROGNAME [-w <secs>] [-c <secs>] [-W <size>] [-C <size>] [-i] -f <file>\n";
 	print "  $PROGNAME [-h | --help]\n";
 	print "  $PROGNAME [-V | --version]\n";
 }
 
 sub print_help () {
-	print_revision($PROGNAME, '$Id: check_file_age.pl,v 1.2 2003/10/21 15:56:35 tonvoon Exp $');
+	print_revision($PROGNAME, '@NP_VERSION@');
 	print "Copyright (c) 2003 Steven Grimm\n\n";
 	print_usage();
 	print "\n";
-	print "  <secs>  File must be no more than this many seconds old\n";
-	print "  <size>  File must be at least this many bytes long\n";
+	print "  -i | --ignore-missing :  return OK if the file does not exist\n";
+	print "  <secs>  File must be no more than this many seconds old (default: warn 240 secs, crit 600)\n";
+	print "  <size>  File must be at least this many bytes long (default: crit 0 bytes)\n";
 	print "\n";
 	support();
 }
