@@ -3,7 +3,7 @@
 * Nagios check_dbi plugin
 * 
 * License: GPL
-* Copyright (c) 2011 Nagios Plugins Development Team
+* Copyright (c) 2011-2014 Nagios Plugins Development Team
 * Author: Sebastian 'tokkee' Harl <sh@teamix.net>
 * 
 * Description:
@@ -30,8 +30,8 @@
 *****************************************************************************/
 
 const char *progname = "check_dbi";
-const char *copyright = "2011";
-const char *email = "nagiosplug-devel@lists.sourceforge.net";
+const char *copyright = "2014";
+const char *email = "devel@nagios-plugins.org";
 
 #include "common.h"
 #include "utils.h"
@@ -562,7 +562,7 @@ print_help (void)
 	printf ("                   %s\n", _("(ignore the query result)"));
 	printf ("\n");
 
-	printf (UT_TIMEOUT, DEFAULT_SOCKET_TIMEOUT);
+	printf (UT_CONN_TIMEOUT, DEFAULT_SOCKET_TIMEOUT);
 
 	printf (UT_VERBOSE);
 
