@@ -1,14 +1,14 @@
 /*****************************************************************************
 * 
-* Nagios check_disk plugin
+* Nagios check_swap plugin
 * 
 * License: GPL
 * Copyright (c) 2000 Karl DeBisschop (kdebisschop@users.sourceforge.net)
-* Copyright (c) 2000-2007 Nagios Plugins Development Team
+* Copyright (c) 2000-2014 Nagios Plugins Development Team
 * 
 * Description:
 * 
-* This file contains the check_disk plugin
+* This file contains the check_swap plugin
 * 
 * 
 * This program is free software: you can redistribute it and/or modify
@@ -28,8 +28,8 @@
 *****************************************************************************/
 
 const char *progname = "check_swap";
-const char *copyright = "2000-2007";
-const char *email = "nagiosplug-devel@lists.sourceforge.net";
+const char *copyright = "2000-2014";
+const char *email = "devel@nagios-plugins.org";
 
 #include "common.h"
 #include "popen.h"
@@ -346,8 +346,11 @@ main (int argc, char **argv)
 # endif /* HAVE_SWAP */
 #endif /* HAVE_PROC_MEMINFO */
 
-	/* if total_swap_mb == 0, let's not divide by 0 */
-	if(total_swap_mb) {
+	/* if total_swap_mb == 0, swap is most likely missing or disabled and should go critical */
+	if(total_swap_mb == 0) {
+		percent_used = 100;
+		status = "- Swap is either disabled, not present, or of zero size. ";
+	} else if(total_swap_mb > 0) {
 		percent_used = 100 * ((double) used_swap_mb) / ((double) total_swap_mb);
 	} else {
 		percent_used = 0;
@@ -538,13 +541,14 @@ print_help (void)
   printf (" %s\n", "-c, --critical=INTEGER");
   printf ("    %s\n", _("Exit with CRITICAL status if less than INTEGER bytes of swap space are free"));
   printf (" %s\n", "-c, --critical=PERCENT%%");
-  printf ("    %s\n", _("Exit with CRITCAL status if less than PERCENT of swap space is free"));
+  printf ("    %s\n", _("Exit with CRITICAL status if less than PERCENT of swap space is free"));
   printf (" %s\n", "-a, --allswaps");
   printf ("    %s\n", _("Conduct comparisons for all swap partitions, one by one"));
 	printf (UT_VERBOSE);
 
 	printf ("\n");
   printf ("%s\n", _("Notes:"));
+  printf (" %s\n", _("Both INTEGER and PERCENT thresholds can be specified, they are all checked."));
   printf (" %s\n", _("On AIX, if -a is specified, uses lsps -a, otherwise uses lsps -s."));
 
 	printf (UT_SUPPORT);
@@ -556,6 +560,6 @@ void
 print_usage (void)
 {
 	printf ("%s\n", _("Usage:"));
-  printf ("%s [-av] -w <percent_free>%% -c <percent_free>%%\n",progname);
-  printf ("%s [-av] -w <bytes_free> -c <bytes_free>\n", progname);
+  printf (" %s [-av] -w <percent_free>%% -c <percent_free>%%\n",progname);
+  printf ("  -w <bytes_free> -c <bytes_free> [-n <state>}\n");
 }
