@@ -118,6 +118,10 @@ char *fperfdata (const char *,
  int,
  double);
 
+/* string case changes */
+void strntoupper (char * test_char, int size);
+void strntolower (char * test_char, int size);
+
 /* The idea here is that, although not every plugin will use all of these, 
    most will or should.  Therefore, for consistency, these very common 
    options should have only these meanings throughout the overall suite */
@@ -173,28 +177,33 @@ char *fperfdata (const char *,
  -c, --critical=RANGE\n\
     Critical range\n")
 
-#define UT_TIMEOUT _("\
+#define UT_CONN_TIMEOUT _("\
  -t, --timeout=INTEGER\n\
     Seconds before connection times out (default: %d)\n")
 
+#define UT_PLUG_TIMEOUT _("\
+ -t, --timeout=INTEGER\n\
+    Seconds before plugin times out (default: %d)\n")
+
 #ifdef NP_EXTRA_OPTS
 #define UT_EXTRA_OPTS _("\
  --extra-opts=[section][@file]\n\
-    Read options from an ini file. See http://nagiosplugins.org/extra-opts\n\
+    Read options from an ini file. See\n\
+    https://www.nagios-plugins.org/doc/extra-opts.html\n\
     for usage and examples.\n")
 #else
-#define UT_EXTRA_OPTS ""
+#define UT_EXTRA_OPTS " \b"
 #endif
 
 #define UT_THRESHOLDS_NOTES _("\
  See:\n\
- http://nagiosplug.sourceforge.net/developer-guidelines.html#THRESHOLDFORMAT\n\
+ https://www.nagios-plugins.org/doc/guidelines.html#THRESHOLDFORMAT\n\
  for THRESHOLD format and examples.\n")
 
 #define UT_SUPPORT _("\n\
-Send email to nagios-users@lists.sourceforge.net if you have questions\n\
-regarding use of this software. To submit patches or suggest improvements,\n\
-send email to nagiosplug-devel@lists.sourceforge.net\n\n")
+Send email to help@nagios-plugins.org if you have questions regarding use\n\
+of this software. To submit patches or suggest improvements, send email to\n\
+devel@nagios-plugins.org\n\n")
 
 #define UT_NOWARRANTY _("\n\
 The nagios plugins come with ABSOLUTELY NO WARRANTY. You may redistribute\n\
